summaryrefslogtreecommitdiff
path: root/tap.h
diff options
context:
space:
mode:
Diffstat (limited to 'tap.h')
-rw-r--r--tap.h13
1 files changed, 9 insertions, 4 deletions
diff --git a/tap.h b/tap.h
index 38be2c6..39ce2ab 100644
--- a/tap.h
+++ b/tap.h
@@ -34,12 +34,17 @@
*/
int TapOpen(const char *filename);
/* Write a block of memory to the TAP file.
*/
-void TapWrite(const unsigned char mem[0x1000],
- unsigned addr,
+void TapBasic(const unsigned char *base,
unsigned len,
- int is_code);
+ unsigned run_line);
+
+/* Write a block of memory to the TAP file.
+*/
+void TapBinary(const unsigned char mem[0x1000],
+ unsigned addr,
+ unsigned len);
/* Close the TAP file.
*/
@@ -34,12 +34,17 @@
*/
int TapOpen(const char *filename);
-/* Write a block of memory to the TAP file.
+/* Write a BASIC file to the TAP file.
*/